<?php
/**
 * Sample implementation of the Custom Header feature.
 *
 * You can add an optional custom header image to header.php like so ...
 *
	<?php if ( get_header_image() ) : ?>
	<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home">
		<img src="<?php header_image(); ?>" width="<?php echo esc_attr( get_custom_header()->width ); ?>" height="<?php echo esc_attr( get_custom_header()->height ); ?>" alt="">
	</a>
	<?php endif; // End header image check. ?>
 *
 * @link https://developer.wordpress.org/themes/functionality/custom-headers/
 *
 * @package Super_Blog
 */

/**
 * Set up the WordPress core custom header feature.
 *
 * @uses super_blog_header_style()
 */
function super_blog_custom_header_setup() {
	add_theme_support( 'custom-header', apply_filters( 'super_blog_custom_header_args', array(
		'default-image'          => '',
		'default-text-color'     => '455a64',
		'width'                  => 1920,
		'height'                 => 410,
		'flex-height'            => true,
		'wp-head-callback'       => 'super_blog_header_style',
		'header-text'            => true,
		'default-image'			 => '%s/assets/images/camera-flower.jpg',
	) ) );

	/*
	 * Default custom headers packaged with the theme.
	 * %s is a placeholder for the theme template directory URI.
	 */
	register_default_headers( array(		
		'camera-flower' => array(
			'url'           => '%s/assets/images/camera-flower.jpg',
			'thumbnail_url' => '%s/assets/images/camera-flower.jpg',
			'description'   => _x( 'camera-flower', 'Camera and Flower', 'super-blog' )
		),	

		'laptop-glass' => array(
			'url'           => '%s/assets/images/laptop-glass.jpg',
			'thumbnail_url' => '%s/assets/images/laptop-glass.jpg',
			'description'   => _x( 'laptop-glass', 'Laptop and Glass', 'super-blog' )
		),

		'diary' 	=> array(
			'url'           => '%s/assets/images/diary.jpg',
			'thumbnail_url' => '%s/assets/images/diary.jpg',
			'description'   => _x( 'diary', 'Diary', 'super-blog' )
		),

		'laptop-cup' => array(
			'url'           => '%s/assets/images/laptop-cup.jpg',
			'thumbnail_url' => '%s/assets/images/laptop-cup.jpg',
			'description'   => _x( 'laptop-cup', 'Laptop and Cup', 'super-blog' )
		),
					
	) );
}
add_action( 'after_setup_theme', 'super_blog_custom_header_setup' );

if ( ! function_exists( 'super_blog_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog.
 *
 * @see super_blog_custom_header_setup().
 */
function super_blog_header_style() {
	$header_text_color = get_header_textcolor();

	/*
	 * If no custom options for text are set, let's bail.
	 * get_header_textcolor() options: Any hex value, 'blank' to hide text. Default: HEADER_TEXTCOLOR.
	 */
	if ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color ) {
			return;
	}

	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( ! display_header_text() ) :
	?>
		.site-title,
		.site-description {
			position: absolute;
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that.
		else :
	?>
		.site-title a,
		.site-description {
			color: #<?php echo esc_attr( $header_text_color ); ?>;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif;
